@@ -133,7 +133,7 @@ class TempAtoms:
             self.positions = [[i * Bohr for i in xyz] for xyz in self.positions]
             self.cell = [[i * Bohr for i in xyz] for xyz in self.cell]
             self.energy *= Hartree
-            self.forces = [[i * Hartree * Bohr for i in xyz]
+            self.forces = [[i * Hartree / Bohr for i in xyz]
                            for xyz in self.forces]
 
         elif input_units == 'si' and output_units == 'atomic':
@@ -163,7 +163,7 @@ def read_runnerdata(
     ----------
     infile : TextIOWrapper
         Python fileobj with the target input.data file.
-    index : int or slice, _default_ -1
+    index : int or slice
         The slice of structures which should be returned. Returns only the last
         structure by default.
     input_units : str
@@ -173,7 +173,7 @@ def read_runnerdata(
 
     Returns
     -------
-    Atoms : Atoms
+    images : Atoms
         All information about the structures within `index` of `infile`,
         including symbols, positions, atomic charges, and cell lattice. Every
         `Atoms` object has a `RunnerSinglePointCalculator` attached with
@@ -238,8 +238,7 @@ def read_runnerdata(
             aseatoms = atoms.to_aseatoms()
             images.append(aseatoms)
 
-    for aseatoms in images[index]:
-        yield aseatoms
+    yield images[index]
 
 
 @writer
