@@ -582,7 +582,7 @@ class RunnerFitResults:
         The units of the energy and force RMSE.
     """
 
-    def __init__(self, infile: Optional[Union[str, TextIO]]) -> None:
+    def __init__(self, infile: Optional[Union[str, TextIO]] = None) -> None:
         """Initialize the object.
 
         Parameters
@@ -679,7 +679,7 @@ class RunnerSplitTrainTest:
     This class stores this data and enables to read it from Mode 1 output files.
     """
 
-    def __init__(self, infile: Optional[Union[str, TextIO]]) -> None:
+    def __init__(self, infile: Optional[Union[str, TextIO]] = None) -> None:
         """Initialize the object.
 
         Parameters
@@ -709,6 +709,9 @@ class RunnerSplitTrainTest:
             Data will be read from this fileobj. The file should contain the
             stdout from a RuNNer Mode 1 run.
         """
+        self.train = []
+        self.test = []
+
         for line in infile:
             if 'Point is used for' in line:
                 # In Python, indices start at 0, therefore we subtract 1.
