@@ -151,9 +151,9 @@ class SymmetryFunction:
     @property
     def tag(self) -> str:
         """Show a human-readable equivalent of the `sftype` parameter."""
-        if self.sftype in [2]:
+        if self.sftype in [2, 22, 23]:
             tag = 'radial'
-        elif self.sftype in [3, 4, 5]:
+        elif self.sftype in [3, 4, 5, 25, 26, 27]:
             tag = 'angular'
         else:
             tag = 'unknown'
